@@ -118,6 +118,8 @@ def init_set_y(model, _x):
     # (not yet added to main `y` set here)
     links = model.config_model.get_key('links', None)
     if links:
+        links = {k:v for k, v in model.config_model.links.items() if
+            len(set(k.split(",")).difference(_x)) == 0}
         _y_trans = transmission.get_transmission_techs(links)
         transmission_techs = list(set([list(v.keys())[0]
                                   for k, v in links.items()]))
@@ -126,7 +128,8 @@ def init_set_y(model, _x):
             locs = link.split(',')
             _x_trans.add(locs[0])
             _x_trans.add(locs[1])
-        _x_trans = list(_x_trans)
+        # Avoid adding in locations that may have been removed by use of "subset_x"
+        _x_trans = list(_x_trans.intersection(_x))
     else:
         _y_trans = []
         _x_trans = []
@@ -134,9 +137,13 @@ def init_set_y(model, _x):
 
     _y = set()
     _x = _x.copy()
+
     for k, v in model.config_model.locations.items():
+        if k not in _x:
+            continue
         if 'techs' in v.keys():
-            if set(v.techs).intersection(transmission_techs): # transmission nodes have only tranmission techs in techs list
+            # transmission nodes have only transmission techs in techs list
+            if set(v.techs).intersection(transmission_techs) and k in _x:
                 _x.remove(k)
             else:
                 for y in v.techs:
@@ -185,7 +192,7 @@ def init_set_y(model, _x):
     _y_sd = _y_supply + _y_demand + _y_unmet
 
     # Subset of storage technologies
-    _y_store = [y for y in np.concatenate((_y_storage,_y_supply_plus)) if
+    _y_store = _y_storage + [y for y in _y_supply_plus if
                 any([model.get_option(y + '.constraints.s_cap.max', x=x) +
                      model.get_option(y + '.constraints.s_time.max', x=x) +
                      model.get_option(y + '.constraints.s_cap.equals', x=x) +
@@ -358,8 +365,10 @@ def init_y_trans(model):
             model._locations[y] = 0
 
         # Create representation of location-tech links
+        links = {k:v for k, v in model.config_model.links.items() if
+            len(set(k.split(",")).difference(model._sets['x_transmission'])) == 0}
         tree = transmission.explode_transmission_tree(
-            model.config_model.links, model._sets['x_transmission']
+            links, model._sets['x_transmission']
         )
 
         # Populate locations matrix with allowed techs and overrides
@@ -388,3 +397,32 @@ def init_y_trans(model):
                             model.set_option(y + '.constraints.e_con', False, x=x)
                         else:
                             model._locations.at[x, colname] = tree[x][y].get_key(c)
+
+def init_set_loc_tech(model):
+    def create_loc_tech(tech):
+        return [":".join([x, y]) for x in model._sets["x"]
+        for y in model._sets[tech] if model._locations.at[x, y]]
+    return_dict = dict()
+    return_dict["loc_tech_area"] = create_loc_tech("y_r_area")
+    return_dict["loc_tech_store"] = create_loc_tech("y_store")
+    return_dict["loc_tech_storage"] = create_loc_tech("y_storage")
+    return_dict["loc_tech_supply_plus_finite_r"] = create_loc_tech("y_sp_finite_r")
+    return_dict["loc_tech"] = create_loc_tech("y")
+    return_dict["loc_tech_r2"] = create_loc_tech("y_sp_r2")
+    return_dict["loc_tech_export"] = create_loc_tech("y_export")
+    return_dict["loc_tech_purchase"] = create_loc_tech("y_purchase")
+    return_dict["loc_tech_milp"] = create_loc_tech("y_milp")
+    return_dict["loc_tech_transmission"] = create_loc_tech("y_transmission")
+    return_dict["loc_tech_finite_r"] = create_loc_tech("y_finite_r")
+    return_dict["loc_tech_demand"] = create_loc_tech('y_demand')
+    return_dict["loc_tech_supply"] = create_loc_tech('y_supply')
+    return_dict["loc_tech_supply_plus"] = create_loc_tech('y_supply_plus')
+    return_dict["loc_tech_conversion"] = create_loc_tech('y_conversion')
+    return_dict["loc_tech_conversion_plus"] = create_loc_tech('y_conversion_plus')
+    return_dict["loc_tech_unmet"] = create_loc_tech('y_unmet')
+    return_dict["loc_tech_2out"] = create_loc_tech('y_cp_2out')
+    return_dict["loc_tech_3out"] = create_loc_tech('y_cp_3out')
+    return_dict["loc_tech_2in"] = create_loc_tech('y_cp_2in')
+    return_dict["loc_tech_3in"] = create_loc_tech('y_cp_3in')
+
+    return return_dict
